Old Laptop Batteries Could Help Power the Developing World | MIT Technology Review
Description: Millions of batteries discarded with computers have more than enough life to power home lighting for one year, researchers in India say.
Date: 2014-12-03T17:15:00-05:00

## MIT Technology Review

Unsupported browser: Your browser does not meet modern web standards. See how it scores »

{ action.text }

# Discarded Laptop Batteries Keep the Lights On

## Collection

### Innovative Technologies for Increasing Efficiency

#### Brought to you by

- 20 comments

# Discarded Laptop Batteries Keep the Lights On

Millions of batteries discarded with computers have more than enough life to power home lighting for one year, researchers in India say.

- By David Talbot on December 3, 2014

A street vendor in India uses a light powered by refurbished battery cells.

Many of the estimated 50 million lithium-ion laptop batteries discarded every year could provide electricity storage sufficient to light homes in poor countries, researchers at IBM say.

In work being aired this week at a conference in San Jose, researchers at IBM Research India in Bangalore found that at least 70 percent of all discarded batteries have enough life left to power an LED light at least four hours a day for a year.

While it’s possible to combine LED lights with solar panels and rechargeable batteries (see “Innovators Under 35: Evans Wadongo”), using discarded batteries could make the approach far cheaper.

“The most costly component in these systems is often the battery,” says Vikas Chandan, a research scientist at the lab’s Smarter Energy Group, who led the project. “In this case, the most expensive part of your storage solution is coming from trash.”

The IBM group, working with a hardware R&D firm called RadioStudio, tore open discarded laptop battery packaging and extracted individual storage units called cells, tested those individually to pick out the good ones, and recombined them to form refurbished battery packs. Then, after adding charging dongles as well as circuitry to prevent overheating, they gave them to five users in Bangalore who lived in slums or operated sidewalk carts.

Three months later, the users said the battery packs had worked well; the main request was for rat-resistant wires and brighter bulbs, says Mohit Jain, a research engineer with the group. A revised setup is now being tested.

Around 50 million laptop and desktop computers are discarded in the United States every year, according to the Environmental Protection Agency. Meanwhile, in India alone, about 400 million people lack grid-connected electricity.

IBM is not considering this as a business but says the technology could be offered free to poor countries.

## MIT Technology Review Custom: Technology Insights

### Simplifying IT: Can You? Should You?

This Technology Insights Custom Report will help business and IT professionals recognize and root out causes of IT complexity.

Free download courtesy of Pure Storage: Download report

### 20 comments. Share your thoughts » 0 comments about this story. Start the discussion »

Credit: Courtesy of IBM Research India

Tagged: Energy, Materials, batteries, developing world

Reprints and Permissions | Send feedback to the editor

- # Innovative Technologies for Increasing Efficiency

  In this content collection, MIT Technology Review explores emerging technologies with the potential to boost efficiency in a variety of areas, leading to greener power plants, more cost-effective building-cooling and even “smart” glasses. Also available within this collection is a free download from MIT Technology Review Custom:

  View Collection »

  Brought to you by:

- # Record-Breaking Solar Cell Points the Way to Cheaper Power

  12

- # Sharp Demonstrates Ultra-Efficient Solar Cells

  9

- # Winners of the Nobel Prize for Physics Enabled Ultra-Efficient Lighting

  5

- # Solar Panels That Configure Themselves

  31

- # Water-Repellent Coating Could Make Power Plants Greener

  8

- # Google Glass Is Dead; Long Live Smart Glasses

  26

- # Material Cools Buildings by Sending Heat into Space

  36

- View More Reports

- # The Top Technology Failures of 2014

  What do the latest technologies to flop, fizzle, and flame out tell us about innovation?

  Continue

  18

- # 2014 in Biomedicine: Rewriting DNA, Decoding the Brain, and a GMO Paradox

  From genetically modified foods to gene therapy, 2014 was a big year for rewriting biology.

  Continue

  1

- # In Praise of Efficient Price Gouging

  Uber’s most important innovation is the way it prices its services. But that innovation has not been unreservedly welcomed...

  Continue

  31

- # 2014 in Computing: Breakthroughs in Artificial Intelligence

  The past year saw progress in developing hardware and software capable of human feats of intelligence.

  Continue

  8

- # 2014 in Materials: Rhubarb Batteries, the Gigafactory, and Printing Body Parts

  In 2014, advanced materials let humans scale glass walls and helped clear the way for cheap, clean energy.

  Continue

  2

- # Shining Light on Madness

  Drugs for psychiatric illnesses aren’t very effective. But new research is offering renewed hope for better medicines.

  Continue

  5

David Talbot Editor

View Profile »

Follow @David_A_Talbot

- RSS

- # 2014 in Energy: Dire Warnings, Slow Progress, and a Fusion Boast

  2

- # Hundreds of Portuguese Buses and Taxis Are Also Wi-Fi Routers

  6

- # Cuba’s Internet Revolution Faces Economic and Political Realities

  5

- # Lima Climate Accord Might Boost Renewables

  50

- # Desalination out of Desperation

  79

- # Researchers Will Study Police Confrontations Via Body Cameras

  5

- # Artificial Skin That Senses, and Stretches, Like the Real Thing

  0

- # Discarded Laptop Batteries Keep the Lights On

  20

- See all from this author

- ### 19 hours ago

  # Best of 2014: The Revolutionary Technique That Quietly Changed Machine Vision Forever

- ### 1 day ago

  # Seven Stories You Shouldn’t Miss
  (Week Ending January 3, 2014)

- ### 1 day ago

  # Best of 2014: How Google "Translates" Pictures into Words Using Vector Space Mathematics

- ### 2 days ago

  # Best of 2014: How the Friendship Paradox Makes Your Friends Better Than You Are

- ### 3 days ago

  # A Microfluidic Device Squeezes Cells to Deliver Drugs

- # Innovative Technologies for Increasing Efficiency

  Brought to you by

- ### 3 days ago

  # The Year in Technological Failure

- ### 3 days ago

  # How Can an Aircraft Disappear Over the Ocean?

- ### 3 days ago

  # How an Upgraded Tesla Travels 400 Miles on a Charge

- ### 3 days ago

  # IBM Builds a Brain-Inspired Chip Using Phase-Change Memory

- ### 3 days ago

  # Best of 2014: Evidence Grows That Online Social Networks Have Insidious Negative Effects

- ### 4 days ago

  # Reading and Rewriting DNA: The Year in Biomedicine

- ### 4 days ago

  # Best of 2014: Google's Secretive DeepMind Startup Unveils a "Neural Turing Machine"

- ### 5 days ago

  # Breakthroughs in Artificial Intelligence from 2014

- ### 6 days ago

  # Rechargeable Fuel and Printed Body Parts: The Year in Materials

- ### 1 week ago

  # The Biggest Technology Stories of the Year, Told in Numbers

- See full archive

- ### 3 days ago

  # The Year in Technological Failure

- ### 1 day ago

  # Best of 2014: How Google "Translates" Pictures into Words Using Vector Space Mathematics

- ### 5 days ago

  # Breakthroughs in Artificial Intelligence from 2014

- ### 3 days ago

  # IBM Builds a Brain-Inspired Chip Using Phase-Change Memory

- ### 3 days ago

  # How an Upgraded Tesla Travels 400 Miles on a Charge

- ### 4 days ago

  # Best of 2014: Google's Secretive DeepMind Startup Unveils a "Neural Turing Machine"

- ### 2 months ago

  # Google's Secretive DeepMind Startup Unveils a "Neural Turing Machine"

- ### 1 month ago

  # How Google "Translates" Pictures into Words Using Vector Space Mathematics

- ### 6 days ago

  # Rechargeable Fuel and Printed Body Parts: The Year in Materials

- ### 4 days ago

  # Reading and Rewriting DNA: The Year in Biomedicine

- ### 12 months ago

  # How Google Cracked House Number Identification in Street View

- ### 2 days ago

  # Best of 2014: How the Friendship Paradox Makes Your Friends Better Than You Are

- ### 8 years ago

  # Tracing Your Ancestry

- ### 2 weeks ago

  # Meet the Dogged Researchers Who Try to Unmask Haters Online

- ### 3 days ago

  # Best of 2014: Evidence Grows That Online Social Networks Have Insidious Negative Effects

- ### 1 week ago

  # Hundreds of Buses and Taxis in Portugal Form a Mesh Wi-Fi Network

- See full archive

- ### 3 days ago

  # The Year in Technological Failure

- ### 1 day ago

  # Best of 2014: How Google "Translates" Pictures into Words Using Vector Space Mathematics

- ### 3 days ago

  # IBM Builds a Brain-Inspired Chip Using Phase-Change Memory

- ### 5 days ago

  # Breakthroughs in Artificial Intelligence from 2014

- ### 4 days ago

  # Reading and Rewriting DNA: The Year in Biomedicine

- ### 1 week ago

  # Singapore Plans Driverless Vehicles, But You’ll Have to Share

- ### 1 week ago

  # A Solid-State Battery Could Double Electric Car Range

- ### 1 week ago

  # Hundreds of Buses and Taxis in Portugal Form a Mesh Wi-Fi Network

- ### 2 months ago

  # Published for the First Time: a 1959 Essay by Isaac Asimov on Creativity

- ### 2 weeks ago

  # We’re Doing Autism Research All Wrong

- ### 4 years ago

  # Astronomers Find First Evidence of Other Universes

- ### 5 months ago

  # Forget the Shortest Route Across a City; New Algorithm Finds the Most Beautiful

- ### 2 years ago

  # Given Tablets but No Teachers, Ethiopian Children Teach Themselves

- ### 1 year ago

  # Government Lab Reveals It Has Operated Quantum Internet for Over Two Years

- ### 19 hours ago

  # Best of 2014: The Revolutionary Technique That Quietly Changed Machine Vision Forever

- ### 1 day ago

  # Seven Stories You Shouldn’t Miss
  (Week Ending January 3, 2014)

- See full archive

Show comments »
Conversation powered by Livefyre

## New & Trending

- Tech Flops 2014
- Year in AI
- Phase-Change Brain
- 400-Mile Tesla
- Materials in 2014
- Biotech in 2014
- Troll Hunters

- # Best of 2014: The Revolutionary Technique That Quietly Changed Machine Vision Forever

- # Seven Must-Read Stories (Week Ending January 3, 2014)

- # Best of 2014: How Google "Translates" Pictures into Words Using Vector Space Mathematics

- # Best of 2014: How the Friendship Paradox Makes Your Friends Better Than You Are

## From the Archives

- # 10 Emerging Technologies

  ## 8 years ago

- # A Study in Complexity

  ## 17 years ago

- # Stopping Pain

  ## 11 years ago

- # Toward Sharing the Genome

  ## 14 years ago

- more
- 2012
- 2011
- 2010
- 2009
- 2008
- ...1899
- more

Close

# Introducing MIT Technology Review Insider.

### Already a Magazine subscriber?

You're automatically an Insider. It's easy to activate or upgrade your account.

Activate Your Account

### Become an Insider

It's the new way to subscribe. Get even more of the tech news, research, and discoveries you crave.

Sign Up

### Learn More

Find out why MIT Technology Review Insider is for you and explore your options.

Show Me